==> haskell-netlink-1.1.1.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-7lToiwlODZtJ2LH0SEVk93
key:                  netlink-1.1.1.0-7lToiwlODZtJ2LH0SEVk93
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  36ff4dd967057b01dff61d79116deb7f
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-9.0.2/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-netlink
hs-libraries:         HSnetlink-1.1.1.0-7lToiwlODZtJ2LH0SEVk93
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6 containers-0.6.4.1
    monad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX
    pretty-hex-1.1-9PVICJLEVnj57Z38XoPFDR unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-netlink-1.1.1.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-HQc0LZUzafRLOrLetxcbYT
key:                  netlink-1.1.1.0-HQc0LZUzafRLOrLetxcbYT
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  d720d0fb32c6059ae78b5ceed4922c16
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-9.2.8/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-netlink
hs-libraries:         HSnetlink-1.1.1.0-HQc0LZUzafRLOrLetxcbYT
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 containers-0.6.5.1
    monad-loops-0.4.3-1PoLx7GFY2f6JjKzBe0o6E
    pretty-hex-1.1-LEbBlO3sovq47L6nKFZ3dY unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
